"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var NotificationItem_1 = require("./NotificationItem");
var moment = require("moment");
function NotificationContextProvider(props) {
    var _a = React.useState([]), notifications = _a[0], setNotifications = _a[1];
    function addInfo(message, title) {
        var now = moment.now();
        var noti = __assign(__assign({}, props.infoProps), { id: now + Math.random(), timestamp: now, open: true, variant: NotificationItem_1.NotificationType.info, remainingDuration: props.infoProps.autoHideDuration, message: message,
            title: title });
        addNotification(noti);
    }
    function addWarning(message, title) {
        var now = moment.now();
        var noti = __assign(__assign({}, props.warningProps), { id: now + Math.random(), timestamp: now, open: true, variant: NotificationItem_1.NotificationType.warning, remainingDuration: props.infoProps.autoHideDuration, message: message,
            title: title });
        addNotification(noti);
    }
    function addError(message, title) {
        var now = moment.now();
        var noti = __assign(__assign({}, props.errorProps), { id: now + Math.random(), timestamp: now, open: true, variant: NotificationItem_1.NotificationType.error, remainingDuration: props.infoProps.autoHideDuration, message: message,
            title: title });
        addNotification(noti);
    }
    function addCustomNotification(notification) {
        var now = moment.now();
        addNotification(__assign(__assign({ transitionDuration: 750, enableClickAway: false, snackBarMessageVariant: "body1", snackBarTitleVariant: "h6" }, notification), { id: now + Math.random(), remainingDuration: notification.autoHideDuration, timestamp: now, open: true, variant: NotificationItem_1.NotificationType.custom }));
    }
    function addNotification(noti) {
        if (props.displayOldestOnTop === true) {
            setNotifications(__spreadArrays(notifications, [__assign({}, noti)]));
        }
        else {
            setNotifications(__spreadArrays([__assign({}, noti)], notifications));
        }
    }
    function handleClose(id) {
        setNotifications(notifications.map(function (noti) {
            return noti.id === id ? __assign(__assign({}, noti), { open: false }) : __assign({}, noti);
        }));
    }
    function handleExited(id) {
        setNotifications(notifications.filter(function (noti) {
            if (noti.id === id) {
                return false;
            }
            return true;
        }));
    }
    function handleSetHeight(id, height) {
        setNotifications(notifications.map(function (noti) {
            return noti.id === id ? __assign(__assign({}, noti), { height: height }) : __assign({}, noti);
        }));
    }
    function handleCalcMarginTop(index) {
        var marginTop = 0;
        notifications
            .slice(0, index)
            .forEach(function (noti) { return (marginTop += noti.height || 0); });
        return marginTop + index * 8;
    }
    function calcRemainingDuration(noti) {
        if (noti.autoHideDuration) {
            return noti.autoHideDuration - (moment.now() - noti.timestamp);
        }
        return undefined;
    }
    return (React.createElement(exports.NotificationContext.Provider, { value: {
            addInfo: addInfo,
            addWarning: addWarning,
            addError: addError,
            addCustomNotification: addCustomNotification
        } },
        props.children,
        notifications.map(function (noti, index) { return (React.createElement(NotificationItem_1.NotificationItem, __assign({}, noti, { key: noti.id, index: index, onClose: handleClose, onExited: handleExited, remainingDuration: calcRemainingDuration(noti), onSetHeight: handleSetHeight, onCalcMarginTop: handleCalcMarginTop, anchorOrigin: props.anchorOrigin }))); })));
}
exports.NotificationContextProvider = NotificationContextProvider;
NotificationContextProvider.defaultProps = {
    anchorOrigin: { vertical: "top", horizontal: "right" },
    infoProps: {
        transitionDuration: 750,
        enableClickAway: false,
        autoHideDuration: 2500,
        snackBarStyle: {
            backgroundColor: "green",
            color: "white",
            fontSize: 16
        },
        snackBarMessageVariant: "body1",
        snackBarTitleVariant: "h6"
    },
    warningProps: {
        transitionDuration: 750,
        enableClickAway: false,
        autoHideDuration: 2500,
        snackBarStyle: {
            backgroundColor: "orange",
            color: "white",
            fontSize: 16
        },
        snackBarMessageVariant: "body1",
        snackBarTitleVariant: "h6"
    },
    errorProps: {
        transitionDuration: 750,
        enableClickAway: false,
        snackBarStyle: {
            backgroundColor: "red",
            color: "white",
            fontSize: 16
        },
        snackBarMessageVariant: "body1",
        snackBarTitleVariant: "h6"
    }
};
exports.NotificationContext = React.createContext({});
